This function computes the predictive negative log-likelihood from a DGP emulator with a likelihood layer.
nllik(object, x, y)An updated object is returned with an additional slot named NLL that contains two elements.
The first one, named meanNLL, is a scalar that gives the average negative predicted log-likelihood
across all testing data points. The second one, named allNLL, is a vector that gives the negative predicted
log-likelihood for each testing data point.
an instance of the dgp class and it should be produced by dgp() with likelihood not being NULL;
a matrix where each row is an input testing data point and each column is an input dimension.
a matrix with only one column where each row is a scalar-valued testing output data point.
See further examples and tutorials at https://mingdeyu.github.io/dgpsi-R/.